@@ -5,7 +5,7 @@ def _read(fn):
     return open(fullpath, 'rb').read()
 
 
-player1 = _read('player1')
+dumb_player = _read('dumb_player')
 err_syntax = _read('err_syntax')
-
-__all__ = ['player1', 'err_syntax']
+err_divzero = _read('err_divzero')
+err_badfun = _read('err_badfun')
